import React, { useContext } from "react";
import Head from "next/head";
import MqlServerHealth from "../queries/mql/MqlServerHealth";
import useMqlQuery from "../hooks/useMqlQuery";
import styles from "../styles/Home.module.css";
import MqlContext from "../context/MqlContext/MqlContext";
// Per our notes in useMqlQuery, queryInput must be stable.
var queryInput = {};
export default function MqlContextDemo() {
    // Here is a simple way to access the MQL Server URL directly,
    // as well as a useQuery hook for custom queries
    var _a = useContext(MqlContext), mqlServerUrl = _a.mqlServerUrl, useQuery = _a.useQuery;
    // Here is a simple way to run a custom graphql query against the MQL Server
    var healthCheckData = useQuery({
        query: MqlServerHealth,
        pause: !mqlServerUrl,
    })[0].data;
    // Here is a simple example of the useMqlQuery hook to fetch data to be plotted in a chart
    var query = useMqlQuery({
        queryInput: queryInput,
        metricName: "question_replies",
        limit: 365,
    });
    var data = query.data, queryStatus = query.queryStatus, queryId = query.queryId;
    return (React.createElement("div", { className: styles.container },
        React.createElement(Head, null,
            React.createElement("title", null, "Transform React Demo"),
            React.createElement("link", { rel: "icon", href: "/favicon.ico" })),
        React.createElement("main", { className: styles.main },
            React.createElement("h1", { className: styles.title }, "MqlContext"),
            React.createElement("p", { className: styles.description },
                "MQL Server URL:",
                React.createElement("code", { className: styles.code }, mqlServerUrl)),
            React.createElement("p", { className: styles.description },
                "MQL Server Health Check:",
                React.createElement("code", { className: styles.code }, JSON.stringify(((healthCheckData === null || healthCheckData === void 0 ? void 0 : healthCheckData.healthReport) || [])[0]))),
            React.createElement("p", { className: styles.description },
                "MQL Query ID:",
                React.createElement("code", { className: styles.code }, queryId)),
            React.createElement("p", { className: styles.description },
                "MQL Query Status:",
                React.createElement("code", { className: styles.code }, queryStatus)),
            React.createElement("p", { className: styles.description },
                "MQL Query Chart:",
                React.createElement("code", { className: styles.code }, JSON.stringify(data === null || data === void 0 ? void 0 : data.result)))),
        React.createElement("footer", { className: styles.footer },
            React.createElement("a", { href: "https://vercel.com?utm_source=create-next-app&utm_medium=default-template&utm_campaign=create-next-app", target: "_blank", rel: "noopener noreferrer" },
                "Powered by",
                " ",
                React.createElement("img", { src: "/vercel.svg", alt: "Vercel Logo", className: styles.logo })))));
}
